clear all
close all
clc
format short eng
format compact
%% Safety Coeff
R=1.5;
%% Hyd system
p=350e5;
oil_speed=2; %m/s
%% Aileron Forces and linkage
La=.1;
H=608;
MAX_delta=23.5*2;
plate=.01; %[m] jack plate tickness
ang_speed=60; %[deg/s] max actuation speed
%% Rod material (AISI 4130 steel)
E=205e9; %[Pa] Young modulus
sigmaR=1.11e9; %[Pa] Rupture traction tension
sigma02=951e6; %[Pa] yield stress
rho=7850; %[kg/m^3] steel density
%% computing
%aileron linear force, speed and max movement
F=2*H/La;
MAX_Xj=2*La*tand(MAX_delta/2);
lin_speed=deg2rad(ang_speed)*La;

%rod length (based on ?Xj)
L=1.5*MAX_Xj;
%rod traction
T_diam=sqrt((4*F*R)/(pi*sigma02));
sigma_c=F/(pi*T_diam^2/4);
%rod compression
slend_lim=pi*sqrt(E/sigma02);
slend=4*L/T_diam;
if (slend> slend_lim)
    sigma_cr=pi^2*E/slend^2;
else
    sigma_cr=sigma02-(sigma02^2*slend^2)/(4*pi^2*E);
end
if (sigma_cr>sigma_c)
    diam=T_diam;
else
    diam=T_diam;
    done=0;
    while (done == 0)
        slend=4*L/diam;
        if (slend > slend_lim)
            sigma_cr=pi^2*E/slend^2;
        else
            sigma_cr=sigma02-(sigma02^2*slend^2)/(4*pi^2*E);
        end
        if(sigma_cr>(1.25*sigma_c))
            done=1;
        else
            diam=diam+ T_diam*.02;
        end
    end
end
%% casing pressure withstanding
Hyd_Area=F/p;
Jack_diam=2*sqrt(Hyd_Area/pi+(diam^2/4));
s1=(R*Jack_diam*p)/(sigma02*2);
s2=max(roots([sigma02 2*Jack_diam*sigma02/2 -R*p*(Jack_diam/2)^2]));
s=max([s1 s2]);
%% piping
Max_Flow=pi*((Jack_diam/2)^2-(diam/2)^2)*lin_speed;
pipe_diam=sqrt(4*Max_Flow/pi/oil_speed);
pipe_dist=MAX_Xj+plate+pipe_diam;
%% mass
JackMass=rho*(L*pi*(diam/2)^2*2+(Jack_diam/2)^2*pi*plate);
case_mass=((pi*(Jack_diam+2*s)^2/4*MAX_Xj)-pi*(Jack_diam/2)^2*MAX_Xj)*rho;
top_mass=JackMass+case_mass;
%% Output
disp("Advised rod lenght is "+(L*1e3)+" mm")
disp("Rod diameter should be "+(diam*1e3)+" mm")
disp("Diameter of Hyd Jack should be "+(Jack_diam*1e3)+" mm")
disp("Hydraulic Area should be "+(Hyd_Area*1e4)+" cm^2")
disp("The case should hold "+(p/1e5)+" bar being "+(s*1e3)+" mm thick")
disp("Expect a maximus flow of "+(Max_Flow*1e6)+" cm^3/s")
disp("A total of "+(Hyd_Area*MAX_Xj*1e6)+" cm^3 of oil will be displaced")
disp("The hydraulic jack, without casing, will weight "+(JackMass)+" kg")
disp("With the casing, the hydraulic Jack should weight "+(top_mass)+" kg")
disp("Advised inner diameter of piping: "+(pipe_diam*1e3)+" mm")
disp("Case pipes should be "+(pipe_dist*1e3)+" mm apart")