clear all
close all
clc
format short eng
%% Pump 
RPM=450; %nominal RPM
Q=6.845679991822329e-05; %[m^3/s] flow rate requested 
cylinders=9;
stroke_ratio=.5; %bore over stroke ratio
beta= 20; %[deg] swash plate inclination
dead_stroke=.005; %[m] height of dead space
p=350e5; %[Pa] power the pump must be able to provide
pr=1e4; %[Pa] return pressure
eta_v=1;
%% evaluation
n=RPM/60; %times the displacement is sent for each second
omega=RPM*2*pi/60;
Cil=Q/n/eta_v;
V=Cil/cylinders;
stroke=(V/(stroke_ratio^2*pi))^(1/3);
bore=stroke*stroke_ratio;
Cyl_Area=pi*(bore/2)^2;
d=stroke*cotd(beta); %[m] distance between opposed pistons
D=stroke/sind(beta); %[m] direct link between a TDC piston and a BDC piston
Torque=(p-pr)*Cil/(2*pi); %[Nm] nominal Torque required
Power=Torque*omega;
%% output
disp("Requested flow "+(Q*1e6)+" cm^3/s, max pressure "+(p/1e5)+" bar")
disp("Total pump dispacement should be "+ (Cil*1e6) +" cm^3")
disp("Each of the " + (cylinders) +" cylinders will displace " +(V*1e6) +" cm^3")
disp("Bore: "+(bore*1e3)+" mm")
disp("Stroke: "+(stroke*1e3)+" mm")
disp("Pistons anulus diameter should be "+(d*1e3)+" mm")
disp("Diameter of swash plate is "+(D*1e3)+" mm")
disp("Pump requires "+(Torque)+" Nm of torque for "+(Power)+" W of nominal power @ "+(RPM)+" RPM")